Clarity of writing
==================

.. _clarity-of-writing:

Introduction
------------
The clarity of writing module assesses the readability, grammatical correctness and sentiment of a given body of text.

Usage
-----
To use the module:

.. code-block:: console

    >>> import coast_core
    >>> coast_core.clarity_of_writing.function(to_use)

or:

.. code-block:: console

    >>> from coast_core import clarity_of_writing
    >>> clarity_of_writing.function(to_use)

Functions
---------
.. automodule:: coast_core.clarity_of_writing
    :members:
    :undoc-members:
    :show-inheritance:
